define(
//begin v1.x content
({
	singleSort: "Ordine singolo",
	nestedSort: "Ordine nidificato",
	ascending: "Ascendente",
	descending: "Decrescente",
	sortingState: "${0} - ${1}",
	unsorted: "Non ordinare questa colonna",
	indirectSelectionRadio: "Riga ${0}, selezione singola, casella di opzione",
	indirectSelectionCheckBox: "Riga ${0}, selezione multipla, casella di spunta",
	selectAll: "Seleziona tutto"
})
//end v1.x content
);

